@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 56961 2008-11-25 03:43:14Z CJP $"
-__revision__ = "$Revision: 56961 $"
+__svnid__ = "$Id: Editra.py 57225 2008-12-10 02:59:48Z CJP $"
+__revision__ = "$Revision: 57225 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -552,7 +552,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         @param name: name of window to unregister
 
         """
-        if self._windows.has_key(name):
+        if name in self._windows:
             self._windows.pop(name)
             cur_top = self.GetTopWindow()
             if not len(self._windows):
@@ -589,7 +589,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         @param winname: name of window to query
 
         """
-        if self._windows.has_key(winname):
+        if winname in self._windows:
             return self._windows[winname][1]
         else:
             self._log("[app][warn] the window %s has "
@@ -794,6 +794,7 @@ def PrintHelp():
        "  -d         Turn on console debugging\n"
        "  -D         Turn off console debugging (overrides preferences)\n"
        "  -h         Show this help message\n"
+       "  -p         Run Editra in the profiler\n"
        "  -v         Print version number and exit\n"
        "  -S         Disable single instance checker\n"
        "\nLong Arguments:\n"
@@ -812,7 +813,7 @@ def ProcessCommandLine():
 
     """
     try:
-        opts, args = getopt.getopt(sys.argv[1:], "dhvDS",
+        opts, args = getopt.getopt(sys.argv[1:], "dhpvDS",
                                    ['debug', 'help', 'version', 'auth'])
     except getopt.GetoptError, msg:
         return list(), list()
@@ -851,6 +852,22 @@ def Main():
     """
     opts, args = ProcessCommandLine()
 
+    if '-p' in opts:
+        opts.remove('-p')
+        import hotshot
+        # TODO: make output file configurable via commandline
+        prof = hotshot.Profile("editra.prof")
+        prof.runcall(_Main, opts, args)
+        prof.close()
+    else:
+        _Main(opts, args)
+
+def _Main(opts, args):
+    """Main method
+    @param opts: Commandline options
+    @param args: Commandline arguments
+
+    """
     # Put extern subpackage on path so that bundled external dependancies
     # can be found if needed.
     if not hasattr(sys, 'frozen'):
@@ -933,6 +950,7 @@ def Main():
 
     # 3. Start Applications Main Loop
     dev_tool.DEBUGP("[main][info] Starting MainLoop...")
+    wx.CallAfter(frame.Raise)
     editra_app.MainLoop()
     dev_tool.DEBUGP("[main][info] MainLoop finished exiting application")
     os._exit(0)
