@@ -16,8 +16,8 @@ deduct the requested information.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: pycomp.py 56691 2008-11-06 19:26:42Z CJP $"
-__revision__ = "$Revision: 56691 $"
+__cvsid__ = "$Id: pycomp.py 57118 2008-12-05 02:03:02Z CJP $"
+__revision__ = "$Revision: 57118 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -66,6 +66,9 @@ class Completer(object):
         @return: list or string
 
         """
+        if command is None or (len(command) and command[0].isdigit()):
+            return ''
+
         try:
             cmpl = PyCompleter()
 
@@ -718,7 +721,7 @@ class PyParser:
         if tokentype == tokenize.NUMBER or tokentype == tokenize.STRING:
             return token #token = tokentype
 
-        if tokens.has_key(token):
+        if token in tokens:
             return tokens[token]
         else:
             # NOTE: This part of the parse is where the problem is happening
