@@ -12,8 +12,8 @@ Editra Control Library: ControlBox
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ctrlbox.py 56859 2008-11-20 05:36:31Z CJP $"
-__revision__ = "$Revision: 56859 $"
+__svnid__ = "$Id: ctrlbox.py 57305 2008-12-13 03:34:22Z CJP $"
+__revision__ = "$Revision: 57305 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -55,9 +55,11 @@ class ControlBox(wx.PyPanel):
 
         # Attributes
         self._sizer = wx.BoxSizer(wx.VERTICAL)
-        self._ctrlbar = None
+        self._topb = None
         self._main = None
+        self._botb = None
 
+        # Layout
         self.SetSizer(self._sizer)
         self.SetAutoLayout(True)
 
@@ -68,17 +70,24 @@ class ControlBox(wx.PyPanel):
         @postcondition: A top aligned L{ControlBar} is created.
 
         """
-        if self._ctrlbar is None:
-            self._ctrlbar = ControlBar(self, size=(-1, 24),
-                                       style=CTRLBAR_STYLE_GRADIENT)
-            self._sizer.Insert(0, self._ctrlbar, 0, wx.EXPAND)
+        cbar = self.GetControlBar(pos)
+        if cbar is None:
+            cbar = ControlBar(self, size=(-1, 24),
+                              style=CTRLBAR_STYLE_GRADIENT)
 
-    def GetControlBar(self):
+            self.SetControlBar(cbar, pos)
+
+    def GetControlBar(self, pos=wx.TOP):
         """Get the L{ControlBar} used by this window
         @return: ControlBar or None
 
         """
-        return self._ctrlbar
+        if pos == wx.TOP:
+            cbar = self._topb
+        else:
+            cbar = self._botb
+
+        return cbar
 
     def GetWindow(self):
         """Get the main display window
@@ -87,20 +96,37 @@ class ControlBox(wx.PyPanel):
         """
         return self._main
 
-    def SetControlBar(self, ctrlbar):
+    def SetControlBar(self, ctrlbar, pos=wx.TOP):
         """Set the ControlBar used by this ControlBox
         @param ctrlbar: L{ControlBar}
+        @keyword pos: wx.TOP/wx.BOTTOM
 
         """
-        if self._ctrlbar is not None:
-            self._sizer.Replace(self._ctrlbar, ctrlbar)
-            try:
-                self._ctrlbar.Destroy()
-            except wx.PyDeadObjectError:
-                pass
+        tbar = self.GetControlBar(pos)
+        if pos == wx.TOP:
+            if tbar is None:
+                self._sizer.Insert(0, ctrlbar, 0, wx.EXPAND)
+            else:
+                self._sizer.Replace(self._topb, ctrlbar)
+
+                try:
+                    self._topb.Destroy()
+                except wx.PyDeadObjectError:
+                    pass
+
+            self._topb = ctrlbar
         else:
-            self._sizer.Insert(0, ctrlbar, 0, wx.EXPAND)
-        self._ctrlbar = ctrlbar
+            if tbar is None:
+                self._sizer.Add(ctrlbar, 0, wx.EXPAND)
+            else:
+                self._sizer.Replace(self._botb, ctrlbar)
+
+                try:
+                    self._botb.Destroy()
+                except wx.PyDeadObjectError:
+                    pass
+
+            self._botb = ctrlbar
 
     def SetWindow(self, window):
         """Set the main window control portion of the box. This will be the
@@ -108,12 +134,20 @@ class ControlBox(wx.PyPanel):
         @param window: Any window/panel like object
 
         """
-        if self._main is None:
-            self._main = window
-            self._sizer.Add(self._main, 1, wx.EXPAND)
+        if self.GetWindow() is None:
+            if self._topb is None:
+                self._sizer.Add(window, 1, wx.EXPAND)
+            else:
+                self._sizer.Insert(1, window, 1, wx.EXPAND)
         else:
             self._sizer.Replace(self._main, window)
-            self._main = window
+
+            try:
+                self._main.Destroy()
+            except wx.PyDeadObjectError:
+                pass
+
+        self._main = window
 
 #--------------------------------------------------------------------------#
 
@@ -136,6 +170,13 @@ class ControlBar(wx.PyPanel):
         self._tools = dict(simple=list())
         self._spacing = (5, 5)
 
+        # Drawing related
+        color = wx.SystemSettings_GetColour(wx.SYS_COLOUR_3DFACE)
+        self._color2 = AdjustColour(color, 30)
+        self._color = AdjustColour(color, -20)
+        pcolor = tuple([min(190, x) for x in AdjustColour(self._color, -25)])
+        self._pen = wx.Pen(pcolor, 1)
+
         # Setup
         msizer = wx.BoxSizer(wx.VERTICAL)
         spacer = (0, 0)
@@ -232,14 +273,11 @@ class ControlBar(wx.PyPanel):
 
         # Paint the gradient
         gc = wx.GraphicsContext.Create(dc)
-        col1 = wx.SystemSettings_GetColour(wx.SYS_COLOUR_3DFACE)
-        col2 = AdjustColour(col1, 30)
-        col1 = AdjustColour(col1, -20)
         rect = self.GetClientRect()
-        grad = gc.CreateLinearGradientBrush(0, .5, 0, rect.height, col2, col1)
+        grad = gc.CreateLinearGradientBrush(0, .5, 0, rect.height,
+                                            self._color2, self._color)
 
-        pen_col = tuple([min(190, x) for x in AdjustColour(col1, -25)])
-        gc.SetPen(gc.CreatePen(wx.Pen(pen_col, 1)))
+        gc.SetPen(gc.CreatePen(self._pen))
         gc.SetBrush(grad)
         gc.DrawRectangle(0, 0, rect.width - 0.5, rect.height - 0.5)
 
@@ -274,6 +312,7 @@ class ControlBar(wx.PyPanel):
         self.Refresh()
 
 #--------------------------------------------------------------------------#
+
 def AdjustColour(color, percent, alpha=wx.ALPHA_OPAQUE):
     """ Brighten/Darken input colour by percent and adjust alpha
     channel if needed. Returns the modified color.
@@ -296,42 +335,3 @@ def AdjustColour(color, percent, alpha=wx.ALPHA_OPAQUE):
     green = min(color.Green() + gadj, 255)
     blue = min(color.Blue() + badj, 255)
     return wx.Colour(red, green, blue, alpha)
-
-#--------------------------------------------------------------------------#
-# Test
-if __name__ == '__main__':
-
-    # Setup Display
-    def MakeTestFrame():
-        frame = wx.Frame(None, title="Test ControlBox")
-        fsizer = wx.BoxSizer(wx.VERTICAL)
-
-        cbox = ControlBox(frame)
-        cbox.CreateControlBar()
-
-        cbar = cbox.GetControlBar()
-        cbar.AddTool(wx.ID_ANY, wx.ArtProvider.GetBitmap(wx.ART_ERROR, wx.ART_MENU, (16, 16)), "hello world")
-        cbar.AddTool(wx.ID_ANY, wx.ArtProvider.GetBitmap(wx.ART_WARNING, wx.ART_MENU, (16, 16)), "warning")
-        cbar.AddStretchSpacer()
-        cbar.AddControl(wx.Choice(cbar, wx.ID_ANY, choices=[str(x) for x in range(10)]), wx.ALIGN_RIGHT)
-        cbar.AddControl(wx.Button(cbar, label="New Frame"), wx.ALIGN_RIGHT)
-
-        cbox.SetWindow(wx.TextCtrl(cbox, style=wx.TE_MULTILINE))
-        cbox.Bind(EVT_CTRLBAR, OnControlBar)
-        cbox.Bind(wx.EVT_BUTTON, OnButton)
-
-        fsizer.Add(cbox, 1, wx.EXPAND)
-        return frame
-
-    def OnControlBar(evt):
-        print "ControlBarEvent", evt.GetId()
-
-    def OnButton(evt):
-        print "Button tool clicked"
-        frame = MakeTestFrame()
-        frame.Show()
-
-    APP = wx.App(False)
-    FRAME = MakeTestFrame()
-    FRAME.Show()
-    APP.MainLoop()
