@@ -61,8 +61,8 @@ Requirements:
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: outbuff.py 56777 2008-11-15 00:54:47Z CJP $"
-__revision__ = "$Revision: 56777 $"
+__svnid__ = "$Id: outbuff.py 57103 2008-12-04 03:23:35Z CJP $"
+__revision__ = "$Revision: 57103 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -195,6 +195,11 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
         self.SetReadOnly(True)
         self.SetCaretWidth(0)
 
+        if wx.Platform == '__WXMSW__':
+            self.SetEOLMode(wx.stc.STC_EOL_CRLF)
+        else:
+            self.SetEOLMode(wx.stc.STC_EOL_LF)
+
         #self.SetEndAtLastLine(False)
         self.SetVisiblePolicy(1, wx.stc.STC_VISIBLE_STRICT)
 
@@ -642,9 +647,9 @@ class ProcessThread(threading.Thread):
                 ctypes.windll.kernel32.PeekNamedPipe(handle, None, 0, 0,
                                                      ctypes.byref(avail), None)
                 if avail.value > 0:
-                    read = self._proc.stdout.read(4096)
+                    read = self._proc.stdout.read(avail.value)
                     if read.endswith(os.linesep):
-                        read = read[:-1 * len(os.linesep)] + "\n"
+                        read = read[:-1 * len(os.linesep)]
                 else:
                     if self._proc.poll() is None:
                         time.sleep(1)
