@@ -17,8 +17,8 @@ resource providers for the ArtProvider.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: ed_art.py 52855 2008-03-27 14:53:06Z CJP $"
-__revision__ = "$Revision: 52855 $"
+__cvsid__ = "$Id: ed_art.py 57226 2008-12-10 03:13:03Z CJP $"
+__revision__ = "$Revision: 57226 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -104,8 +104,7 @@ class EditraArt(wx.ArtProvider):
         # If using default theme let the system provide the art when possible
         # this is mostly for GTK where there is a native art provider that can
         # provide theme icons.
-        if Profile_Get('ICONS', 'str').lower() == u'default' and \
-           DEFAULT.has_key(art_id):
+        if Profile_Get('ICONS', 'str').lower() == u'default' and art_id in DEFAULT:
             if client == wx.ART_MENU:
                 size = (16, 16)
             elif client == wx.ART_TOOLBAR:
@@ -120,7 +119,7 @@ class EditraArt(wx.ArtProvider):
             # to be scaled down as scaling up degrades quality.
             if client == wx.ART_TOOLBAR and not wx.Platform == '__WXMAC__':
                 if size == wx.DefaultSize:
-                    size = Profile_Get('ICON_SZ', 'size_tuple')
+                    size = Profile_Get('ICON_SZ', default=(24, 24))
                 img = wx.ImageFromBitmap(bmp)
                 img_sz = img.GetSize()
                 if size[0] < img_sz[0]:
@@ -134,7 +133,7 @@ class EditraArt(wx.ArtProvider):
             # Dont fail on a toolbar icon return a warning icon when nothing is
             # found in the bitmap provider.
             bmp = wx.ArtProvider.GetBitmap(wx.ART_WARNING, client, size)
-        elif art_id in syntax.SyntaxIds():
+        elif art_id in syntax.SYNTAX_IDS:
             # Dont fail when requesting mime type icons, fallback to the system
             # icon for a normal file in this case.
             bmp = wx.ArtProvider.GetBitmap(wx.ART_NORMAL_FILE,
