@@ -18,8 +18,8 @@ a gradient using system defined colors.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_cmdbar.py 56476 2008-10-20 17:55:34Z CJP $"
-__revision__ = "$Revision: 56476 $"
+__svnid__ = "$Id: ed_cmdbar.py 57286 2008-12-12 16:18:54Z CJP $"
+__revision__ = "$Revision: 57286 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -87,19 +87,18 @@ class CommandBar(wx.Panel):
         # Attributes
         self._parent = parent
         self._installed = False
-        self._sizers = dict(psizer=parent.GetSizer(),
-                            h_sizer=wx.BoxSizer(wx.HORIZONTAL),
+        self._sizers = dict(h_sizer=wx.BoxSizer(wx.HORIZONTAL),
                             goto=wx.BoxSizer(),
                             search=wx.BoxSizer(),
                             cmd=wx.BoxSizer())
 
         # Install Controls
-        self._sizers['h_sizer'].Add((8, 8))
+        self._sizers['h_sizer'].Add((8, 0))
         self.close_b = platebtn.PlateButton(self, ID_CLOSE_BUTTON,
                                             bmp=XButton.GetBitmap(),
                                             style=platebtn.PB_STYLE_NOBG)
         self._sizers['h_sizer'].Add(self.close_b, 0, wx.ALIGN_CENTER_VERTICAL)
-        self._sizers['h_sizer'].Add((5, 5))
+        self._sizers['h_sizer'].Add((5, 0))
         self.SetSizer(self._sizers['h_sizer'])
         self.SetAutoLayout(True)
 
@@ -119,8 +118,6 @@ class CommandBar(wx.Panel):
 
         """
         wx.Panel.Hide(self)
-        if self._sizers['psizer'] != None:
-            self._sizers['psizer'].Layout()
         self._parent.SendSizeEvent()
         self._parent.nb.GetCurrentCtrl().SetFocus()
         return True
@@ -139,6 +136,7 @@ class CommandBar(wx.Panel):
             ctrl = self.InstallCommandCtrl()
         else:
             ctrl = None
+        self.Layout()
         return ctrl
 
     def InstallLineCtrl(self):
@@ -150,9 +148,11 @@ class CommandBar(wx.Panel):
         v_sizer = wx.BoxSizer(wx.VERTICAL)
         v_sizer.Add((5, 5))
         linectrl = LineCtrl(self, ID_LINE_CTRL, self._parent.nb.GetCurrentCtrl,
-                            size=(100, 20))
+                            size=(100, -1))
+        linectrl.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
         v_sizer.Add(linectrl, 0, wx.ALIGN_CENTER_VERTICAL)
         v_sizer.Add((4, 4))
+
         go_lbl = wx.StaticText(self, label=_("Goto Line") + ": ")
         if wx.Platform == '__WXMAC__':
             go_lbl.SetFont(wx.SMALL_FONT)
@@ -173,7 +173,9 @@ class CommandBar(wx.Panel):
         h_sizer = wx.BoxSizer(wx.HORIZONTAL)
         v_sizer = wx.BoxSizer(wx.VERTICAL)
         v_sizer.Add((5, 5))
-        cmdctrl = CommandExecuter(self, ID_CMD_CTRL, size=(150, 20))
+        cmdctrl = CommandExecuter(self, ID_CMD_CTRL, size=(150, -1))
+        cmdctrl.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
+
         v_sizer.Add(cmdctrl, 0, wx.ALIGN_CENTER_VERTICAL)
         v_sizer.Add((4, 4))
         cmd_lbl = wx.StaticText(self, label=_("Command") + ": ")
@@ -203,7 +205,12 @@ class CommandBar(wx.Panel):
             spacer = (4, 4)
         v_sizer.Add(spacer)
         search = ed_search.EdSearchCtrl(self, ID_SEARCH_CTRL,
-                                        menulen=5, size=(180, 20))
+                                        menulen=5, size=(180, -1))
+
+        # The small variant is Too small on windows but good on others
+        if wx.Platform != '__WXMSW__':
+            search.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
+
         v_sizer.Add(search, 0, wx.ALIGN_CENTER_VERTICAL)
         v_sizer.Add((4, 4))
         f_lbl = wx.StaticText(self, label=_("Find") + u": ")
@@ -219,7 +226,7 @@ class CommandBar(wx.Panel):
         match_case = wx.CheckBox(self, ID_MATCH_CASE, _("Match Case"))
         match_case.SetValue(search.IsMatchCase())
 
-        regex_cb = wx.CheckBox(self, ID_REGEX, _("Regex"))
+        regex_cb = wx.CheckBox(self, ID_REGEX, _("Regular Expression"))
         regex_cb.SetValue(search.IsRegEx())
 
         # Use the small size controls on osx
@@ -230,7 +237,7 @@ class CommandBar(wx.Panel):
 
         ctrl_sizer.AddMany([(10, 0), (next_btn, 0, wx.ALIGN_CENTER_VERTICAL),
                             ((5, 0)), (pre_btn, 0, wx.ALIGN_CENTER_VERTICAL),
-                            ((8, 0)),
+                            ((5, 0)),
                             (match_case, 0, wx.ALIGN_CENTER_VERTICAL),
                             ((5, 5), 0),
                             (regex_cb, 0, wx.ALIGN_CENTER_VERTICAL)])
@@ -313,19 +320,10 @@ class CommandBar(wx.Panel):
         self.UpdateIcons()
 
     def Show(self, id_=0):
-        """Shows the control and installs it in the parents
-        sizer if not installed already.
+        """Shows the control
         @param id_: Id of control to show in bar
 
         """
-        # Install self in parent
-        if not self._installed and self._sizers['psizer'] != None:
-            self._installed = True
-            self._sizers['psizer'].Add(self, 0, wx.EXPAND)
-            self._sizers['psizer'].Layout()
-            self._parent.SendSizeEvent()
-        wx.Panel.Show(self)
-
         # HACK YUCK, come back and try again when my brain is working
         # Show specified control
         if id_:
@@ -355,6 +353,7 @@ class CommandBar(wx.Panel):
             if ctrl != None:
                 ctrl.SetFocus()
                 ctrl.SelectAll()
+        wx.Panel.Show(self)
 
     def UpdateIcons(self):
         """Refresh icons to current theme settings
