@@ -14,8 +14,8 @@ access point for all common variables in the project.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 56831 2008-11-18 06:05:05Z CJP $"
-__revision__ = "$Revision: 56831 $"
+__svnid__ = "$Id: ed_glob.py 57303 2008-12-13 02:07:58Z CJP $"
+__revision__ = "$Revision: 57303 $"
 
 __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 'ID_SAVEAS', 'ID_SAVEALL',
@@ -39,7 +39,8 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_COMMAND_BAR', 'ID_DOCUMENTATION', 'ID_COMMAND',
             'ID_USE_SOFTTABS', 'ID_DUP_LINE', 'ID_TRANSLATE',
             'I18N_PAGE', 'ID_GOTO_MBRACE', 'ID_HLCARET_LINE', 'ID_SHOW_SB',
-            'ID_REVERT_FILE', 'ID_RELOAD_ENC', 'ID_DOCPROP', 'ID_PASTE_AFTER']
+            'ID_REVERT_FILE', 'ID_RELOAD_ENC', 'ID_DOCPROP', 'ID_PASTE_AFTER',
+            'ID_COLUMN_MODE']
 
 #---- Project Info ----#
 # The project info was moved to another module so it could be accessed
@@ -104,6 +105,7 @@ ID_COPY          = wx.ID_COPY
 ID_PASTE         = wx.ID_PASTE
 ID_PASTE_AFTER   = wx.NewId()
 ID_SELECTALL     = wx.ID_SELECTALL
+ID_COLUMN_MODE   = wx.NewId()
 ID_LINE_EDIT     = wx.NewId()
 ID_BOOKMARK      = wx.NewId()
 ID_ADD_BM        = wx.ID_ADD
@@ -117,6 +119,7 @@ ID_DUP_LINE      = wx.NewId()
 ID_JOIN_LINES    = wx.NewId()
 ID_TRANSPOSE     = wx.NewId()
 ID_FIND          = wx.ID_FIND
+ID_FIND_PREVIOUS = wx.NewId()
 ID_FIND_NEXT     = wx.NewId()
 ID_FIND_REPLACE  = wx.ID_REPLACE
 # Using the system ids automatically disables the menus items
@@ -216,6 +219,7 @@ ID_HTML_GEN      = wx.NewId()
 ID_TEX_GEN       = wx.NewId()
 ID_RTF_GEN       = wx.NewId()
 ID_RUN_LAUNCH    = wx.NewId()
+ID_LAUNCH_LAST   = wx.NewId()
 
 # Help Menu IDs
 ID_ABOUT         = wx.ID_ABOUT
@@ -254,6 +258,7 @@ ID_USB               = wx.NewId()
 ID_UP                = wx.ID_UP
 ID_VI_MODE           = wx.NewId()
 ID_WEB               = wx.NewId()
+ID_READONLY          = wx.NewId()
 
 # Statusbar IDs
 SB_INFO          = 0
