@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 56950 2008-11-24 01:25:08Z CJP $"
-__revision__ = "$Revision: 56950 $"
+__svnid__ = "$Id: ed_main.py 57303 2008-12-13 02:07:58Z CJP $"
+__revision__ = "$Revision: 57303 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -31,12 +31,11 @@ from ed_glob import *
 import util
 import profiler
 import ed_toolbar
+import ed_mpane
 import ed_event
 import ed_msg
-import ed_pages
 import ed_menu
 import ed_print
-import ed_cmdbar
 import ed_statbar
 import ed_mdlg
 import prefdlg
@@ -81,13 +80,11 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         util.SetWindowIcon(self)
 
         # Attributes
+        self._loaded = False
         self.LOG = wx.GetApp().GetLog()
         self._exiting = False
         self._handlers = dict(menu=list(), ui=list())
 
-        #---- Sizers to hold subapplets ----#
-        self.sizer = wx.BoxSizer(wx.VERTICAL)
-
         #---- Setup File History ----#
         self.filehistory = wx.FileHistory(_PGET('FHIST_LVL', 'int', 5))
 
@@ -98,19 +95,15 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         #---- End Statusbar Setup ----#
 
         #---- Notebook that contains the editting buffers ----#
-        edit_pane = wx.Panel(self)
-        self.nb = ed_pages.EdPages(edit_pane, wx.ID_ANY)
-        edit_pane.nb = self.nb
-        self.sizer.Add(self.nb, 1, wx.EXPAND)
-        edit_pane.SetSizer(self.sizer)
-        self._mgr.AddPane(edit_pane, wx.aui.AuiPaneInfo(). \
+        self._mpane = ed_mpane.MainPanel(self)
+        self.nb = self._mpane.GetWindow()
+        self._mgr.AddPane(self._mpane, wx.aui.AuiPaneInfo(). \
                           Name("EditPane").Center().Layer(1).Dockable(False). \
                           CloseButton(False).MaximizeButton(False). \
                           CaptionVisible(False))
 
         #---- Command Bar ----#
-        self._cmdbar = ed_cmdbar.CommandBar(edit_pane, ID_COMMAND_BAR)
-        self._cmdbar.Hide()
+        self._mpane.HideCommandBar()
 
         #---- Setup Toolbar ----#
         self.SetToolBar(ed_toolbar.EdToolBar(self))
@@ -161,6 +154,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
                                        # Edit Menu
                                        (ID_PASTE_AFTER, self.DispatchToControl),
+                                       (ID_COLUMN_MODE, self.DispatchToControl),
                                        (ID_QUICK_FIND, self.OnCommandBar),
                                        (ID_PREF, OnPreferences),
 
@@ -186,7 +180,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                        (ID_CONTACT, self.OnHelp)])
 
         self._handlers['menu'].extend([(l_id, self.DispatchToControl)
-                                       for l_id in syntax.SyntaxIds()])
+                                       for l_id in syntax.SYNTAX_IDS])
 
         # Extra menu handlers (need to work these into above system yet)
         self.Bind(wx.EVT_MENU, self.DispatchToControl)
@@ -205,6 +199,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                      (ID_PASTE_AFTER, self.OnUpdateClipboardUI),
                                      (ID_UNDO, self.OnUpdateClipboardUI),
                                      (ID_REDO, self.OnUpdateClipboardUI),
+                                     (ID_COLUMN_MODE, self.OnUpdateClipboardUI),
                                      # Format Menu
                                      (ID_INDENT, self.OnUpdateFormatUI),
                                      (ID_USE_SOFTTABS, self.OnUpdateFormatUI),
@@ -233,7 +228,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         # Lexer Menu
         self._handlers['ui'].extend([(l_id, self.OnUpdateLexerUI)
-                                     for l_id in syntax.SyntaxIds()])
+                                     for l_id in syntax.SYNTAX_IDS])
 
         # Perspectives
         self._handlers['ui'].extend(self.GetPersectiveHandlers())
@@ -286,10 +281,18 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         app = wx.GetApp()
+
+        # Don't needlessly push and pop events if we only have one window open
+        if self._loaded and len(app.GetMainWindows()) == 1:
+            evt.Skip()
+            return
+
+        # Add or remove handlers from the event stack
         if evt.GetActive():
+            self._loaded = True
 
             # Slow the update interval to reduce overhead
-            wx.UpdateUIEvent.SetUpdateInterval(160)
+            wx.UpdateUIEvent.SetUpdateInterval(205)
             wx.UpdateUIEvent.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
             self.SetExtraStyle(wx.WS_EX_PROCESS_UI_UPDATES)
 
@@ -404,7 +407,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @return: ed_cmdbar.CommandBar
 
         """
-        return self._cmdbar
+        return self._mpane.GetControlBar(wx.BOTTOM)
+
+    def GetEditPane(self):
+        """Get the editor notebook/command bar control
+        @return: ed_mpane.MainPane
+
+        """
+        return self._mpane
 
     def GetFrameManager(self):
         """Returns the manager for this frame
@@ -914,7 +924,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                         ID_UNINDENT, ID_TRANSPOSE, ID_COMMENT, ID_UNCOMMENT,
                         ID_SELECTALL, ID_UNDO, ID_REDO, ID_CUT, ID_COPY,
                         ID_PASTE, ID_LINE_BEFORE, ID_LINE_AFTER, ID_DUP_LINE,
-                        ID_PASTE_AFTER ]
+                        ID_PASTE_AFTER, ID_COLUMN_MODE ]
 
         has_focus = self.FindFocus()
         if has_focus != ctrl and e_id in active_only:
@@ -935,7 +945,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 evt.Skip()
             return
 
-        menu_ids = syntax.SyntaxIds()
+        menu_ids = list(syntax.SYNTAX_IDS)
         menu_ids.extend([ID_SHOW_EOL, ID_SHOW_WS, ID_INDENT_GUIDES, ID_SYNTAX,
                          ID_WORD_WRAP, ID_BRACKETHL, ID_EOL_MAC, ID_EOL_UNIX,
                          ID_EOL_WIN, ID_NEXT_MARK, ID_PRE_MARK, ID_ADD_BM,
@@ -1014,31 +1024,38 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         e_id = evt.GetId()
         focus = self.FindFocus()
         ctrl = self.nb.GetCurrentCtrl()
+        enable = False
         if e_id == ID_UNDO:
-            can_undo = False
             if hasattr(focus, 'CanUndo'):
-                can_undo = focus.CanUndo()
-            evt.Enable(can_undo)
+                enable = focus.CanUndo()
+            evt.Enable(enable)
         elif e_id == ID_REDO:
             can_redo = False
             if hasattr(focus, 'CanRedo'):
-                can_redo = focus.CanRedo()
-            evt.Enable(can_redo)
+                enable = focus.CanRedo()
+            evt.Enable(enable)
         elif e_id in (ID_PASTE, ID_PASTE_AFTER):
             can_paste = False
             if hasattr(focus, 'CanPaste'):
-                can_paste = focus.CanPaste()
-            evt.Enable(can_paste)
+                enable = focus.CanPaste()
+            evt.Enable(enable)
         elif e_id == ID_COPY:
             can_copy = False
             if hasattr(focus, 'CanCopy'):
-                can_copy = focus.CanCopy()
-            evt.Enable(can_copy)
+                enable = focus.CanCopy()
+            evt.Enable(enable)
         elif e_id == ID_CUT:
             can_cut = False
             if hasattr(focus, 'CanCut'):
-                can_cut = focus.CanCut()
-            evt.Enable(can_cut)
+                enable = focus.CanCut()
+            evt.Enable(enable)
+        elif e_id == ID_COLUMN_MODE:
+            if hasattr(focus, 'IsColumnMode'):
+                enable = focus.IsColumnMode()
+                evt.Enable(True)
+            else:
+                evt.Enable(False)
+            evt.Check(enable)
         else:
             evt.Skip()
 
@@ -1072,7 +1089,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             return
 
         e_id = evt.GetId()
-        if e_id in syntax.SyntaxIds():
+        if e_id in syntax.SYNTAX_IDS:
             lang = self.nb.GetCurrentCtrl().GetLangId()
             evt.Check(lang == evt.GetId())
         else:
@@ -1146,11 +1163,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         e_id = evt.GetId()
-        ctrld = { ID_QUICK_FIND : ed_cmdbar.ID_SEARCH_CTRL,
-                  ID_GOTO_LINE : ed_cmdbar.ID_LINE_CTRL,
-                  ID_COMMAND : ed_cmdbar.ID_CMD_CTRL }
-        if e_id in ctrld:
-            self.ShowCommandCtrl(ctrld[e_id])
+        if e_id in (ID_QUICK_FIND, ID_GOTO_LINE, ID_COMMAND):
+            self._mpane.ShowCommandControl(e_id)
         else:
             evt.Skip()
 
@@ -1184,14 +1198,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         except:
             self.PushStatusText(_("Error: Unable to open %s") % page, SB_INFO)
 
-    def ShowCommandCtrl(self, ctrl_id):
-        """Open the Commandbar in command mode.
-        @param ctrl_id: control id to show
-
-        """
-        self._cmdbar.Show(ctrl_id)
-        self.sizer.Layout()
-
     def ModifySave(self):
         """Called when document has been modified prompting
         a message dialog asking if the user would like to save
@@ -1266,6 +1272,7 @@ def OnPreferences(evt):
 
     """
     if evt.GetId() == ID_PREF:
+        cursor = wx.BusyCursor()
         win = wx.GetApp().GetWindowInstance(prefdlg.PreferencesDialog)
         if win is not None:
             win.Raise()
@@ -1273,6 +1280,7 @@ def OnPreferences(evt):
             dlg = prefdlg.PreferencesDialog(None)
             dlg.CenterOnParent()
             dlg.Show()
+        del cursor
     else:
         evt.Skip()
 
