@@ -14,8 +14,8 @@ for managing keybindings and profiles is also provided by this module.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_menu.py 56853 2008-11-19 20:23:26Z CJP $"
-__revision__ = "$Revision: 56853 $"
+__svnid__ = "$Id: ed_menu.py 57303 2008-12-13 02:07:58Z CJP $"
+__revision__ = "$Revision: 57303 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -371,7 +371,7 @@ class KeyBinder(object):
         if len(keys):
             # Set the binding
             cls.keyprofile[item_id] = keys
-        elif cls.keyprofile.has_key(item_id):
+        elif item_id in cls.keyprofile:
             # Clear the binding
             del cls.keyprofile[item_id]
         else:
@@ -471,14 +471,14 @@ class EdMenuBar(wx.MenuBar):
         filemenu.AppendMenu(ed_glob.ID_FHIST, _("Open &Recent"),
                             filehist, _("Recently Opened Files"))
         filemenu.AppendSeparator()
-        filemenu.Append(ed_glob.ID_CLOSE, _("&Close Page") + \
+        filemenu.Append(ed_glob.ID_CLOSE, _("&Close Tab") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_CLOSE),
-                        _("Close Current Page"))
+                        _("Close Current Tab"))
         filemenu.Append(ed_glob.ID_CLOSE_WINDOW,
                         _("Close Window") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_CLOSE_WINDOW),
                         _("Close the current window"))
-        filemenu.Append(ed_glob.ID_CLOSEALL, _("Close All Pages") + \
+        filemenu.Append(ed_glob.ID_CLOSEALL, _("Close All Tabs") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_CLOSEALL),
                         _("Close all open tabs"))
         filemenu.AppendSeparator()
@@ -556,6 +556,9 @@ class EdMenuBar(wx.MenuBar):
         editmenu.Append(ed_glob.ID_SELECTALL, _("Select &All") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_SELECTALL),
                         _("Select All Text in Document"))
+        editmenu.Append(ed_glob.ID_COLUMN_MODE, _("Column Mode") + \
+                        EdMenuBar.keybinder.GetBinding(ed_glob.ID_COLUMN_MODE),
+                        _("Enable column edit mode."), wx.ITEM_CHECK)
         editmenu.AppendSeparator()
         linemenu = EdMenu()
         linemenu.Append(ed_glob.ID_LINE_AFTER, _("New Line After") + \
@@ -604,6 +607,9 @@ class EdMenuBar(wx.MenuBar):
         editmenu.Append(ed_glob.ID_QUICK_FIND, _("&Quick Find") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_QUICK_FIND),
                         _("Open the Quick Find Bar"))
+        editmenu.Append(ed_glob.ID_FIND_PREVIOUS, _("Find Previous") + \
+                        EdMenuBar.keybinder.GetBinding(ed_glob.ID_FIND_PREVIOUS),
+                        _("Goto previous match"))
         editmenu.Append(ed_glob.ID_FIND_NEXT, _("Find Next") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_FIND_NEXT),
                         _("Goto the next match"))
@@ -980,6 +986,7 @@ _DEFAULT_BINDING = { # File Menu
                      ed_glob.ID_PASTE : ("Ctrl", "V"),
                      ed_glob.ID_PASTE_AFTER : ("Ctrl", "Shift", "V"),
                      ed_glob.ID_SELECTALL : ("Ctrl", "A"),
+                     ed_glob.ID_COLUMN_MODE : ("Ctrl", "|"),
                      ed_glob.ID_LINE_AFTER : ("Ctrl", "L"),
                      ed_glob.ID_LINE_BEFORE : ("Ctrl", "Shift", "L"),
                      ed_glob.ID_CUT_LINE : ("Ctrl", "D"),
@@ -989,6 +996,7 @@ _DEFAULT_BINDING = { # File Menu
                      ed_glob.ID_TRANSPOSE : ("Ctrl", "T"),
                      ed_glob.ID_ADD_BM : ("Ctrl", "B"),
                      ed_glob.ID_FIND : ("Ctrl", "Shift", "F"),
+                     ed_glob.ID_FIND_PREVIOUS : ("Shift", "F3"),
                      ed_glob.ID_FIND_NEXT : ("F3",),
                      ed_glob.ID_FIND_REPLACE : ("Ctrl", "R"),
                      ed_glob.ID_QUICK_FIND : ("Ctrl", "F"),
@@ -1013,13 +1021,15 @@ _DEFAULT_BINDING = { # File Menu
                      # Tools Menu
                      ed_glob.ID_COMMAND : ("Ctrl", "E"),
                      ed_glob.ID_KWHELPER : ("Ctrl", "K"),
-                     ed_glob.ID_RUN_LAUNCH : ("F5",)
+                     ed_glob.ID_RUN_LAUNCH : ("F5",),
+                     ed_glob.ID_LAUNCH_LAST : ("Shift", "F5")
                      }
 
 # Set some platform specific keybindigs
 if wx.Platform == '__WXMAC__':
     _DEFAULT_BINDING[ed_glob.ID_NEXT_MARK] = ("Ctrl", "Down")
     _DEFAULT_BINDING[ed_glob.ID_PRE_MARK] = ("Ctrl", "Up")
+    _DEFAULT_BINDING[ed_glob.ID_FIND_PREVIOUS] = ("Ctrl", "Shift", "G")
     _DEFAULT_BINDING[ed_glob.ID_FIND_NEXT] = ("Ctrl", "G")
     _DEFAULT_BINDING[ed_glob.ID_GOTO_LINE] = ("Ctrl", "Shift", "E")
 elif wx.Platform == '__WXMSW__':
@@ -1092,7 +1102,7 @@ def WalkMenu(menu, label, collection):
     @return: dict {menulabel : [menu id, (item1 id, label1),]}
 
     """
-    if not collection.has_key(label):
+    if label not in collection:
         collection[label] = list()
 
     for item in menu.GetMenuItems():
