@@ -13,8 +13,8 @@ This class implements Editra's main notebook control.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 56950 2008-11-24 01:25:08Z CJP $"
-__revision__ = "$Revision: 56950 $"
+__svnid__ = "$Id: ed_pages.py 57300 2008-12-13 00:18:29Z CJP $"
+__revision__ = "$Revision: 57300 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -58,7 +58,6 @@ class EdPages(FNB.FlatNotebook):
                                   style=FNB.FNB_FF2 |
                                         FNB.FNB_X_ON_TAB |
                                         FNB.FNB_SMART_TABS |
-                                        FNB.FNB_BACKGROUND_GRADIENT |
                                         FNB.FNB_DROPDOWN_TABS_LIST |
                                         FNB.FNB_ALLOW_FOREIGN_DND
                             )
@@ -69,6 +68,8 @@ class EdPages(FNB.FlatNotebook):
         self._searchctrl = ed_search.SearchController(self, self.GetCurrentCtrl)
         self._searchctrl.SetLookinChoices(Profile_Get('SEARCH_LOC',
                                                       default=list()))
+        self._searchctrl.SetFileFilters(Profile_Get('SEARCH_FILTER', default=''))
+
         self.pg_num = -1              # Track new pages (aka untitled docs)
         self.control = None
         self.frame = self.GetTopLevelParent() # MainWindow
@@ -85,6 +86,8 @@ class EdPages(FNB.FlatNotebook):
         imgl = wx.ImageList(16, 16)
         txtbmp = wx.ArtProvider.GetBitmap(str(synglob.ID_LANG_TXT), wx.ART_MENU)
         self._index[synglob.ID_LANG_TXT] = imgl.Add(txtbmp)
+        robmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_READONLY), wx.ART_MENU)
+        self._index[ed_glob.ID_READONLY] = imgl.Add(robmp)
         self.SetImageList(imgl)
 
         # Notebook Events
@@ -95,7 +98,7 @@ class EdPages(FNB.FlatNotebook):
         self.Bind(wx.stc.EVT_STC_MODIFIED, self.OnUpdatePageText)
         self._pages.Bind(wx.EVT_LEFT_UP, self.OnLeftUp)
         self._pages.Bind(wx.EVT_LEFT_DCLICK, self.OnLeftDClick)
-        self._pages.Bind(wx.EVT_MIDDLE_UP, lambda evt: self.ClosePage())
+        self._pages.Bind(wx.EVT_MIDDLE_UP, self.OnMClick)
         self.Bind(FNB.EVT_FLATNOTEBOOK_PAGE_CONTEXT_MENU, self.OnTabMenu)
         self.Bind(wx.EVT_MENU, self.OnCopyTabPath, id=ed_glob.ID_COPY_PATH)
         self.Bind(wx.EVT_IDLE, self.OnIdle)
@@ -195,6 +198,11 @@ class EdPages(FNB.FlatNotebook):
 
         return result == wx.ID_YES
 
+    def AddPage(self, page, text, select=True, imgId=-1):
+        """Add a page to the notebook"""
+        FNB.FlatNotebook.AddPage(self, page, text, select, imgId)
+        self.EnsureVisible(self.GetSelection())
+
     def DocDuplicated(self, path):
         """Check for if the given path is open elswhere and duplicate the
         docpointer.
@@ -267,7 +275,8 @@ class EdPages(FNB.FlatNotebook):
         """
         rlist = [(ed_glob.ID_FIND, self._searchctrl.OnShowFindDlg),
                  (ed_glob.ID_FIND_REPLACE, self._searchctrl.OnShowFindDlg),
-                 (ed_glob.ID_FIND_NEXT, self._searchctrl.OnFind)]
+                 (ed_glob.ID_FIND_NEXT, self._searchctrl.OnFind),
+                 (ed_glob.ID_FIND_PREVIOUS, self._searchctrl.OnFind)]
         return rlist
 
     def GetUiHandlers(self):
@@ -275,7 +284,8 @@ class EdPages(FNB.FlatNotebook):
         @return: list of tuples
 
         """
-        return [(ed_glob.ID_FIND_NEXT, self._searchctrl.OnUpdateFindUI), ]
+        return [(ed_glob.ID_FIND_NEXT, self._searchctrl.OnUpdateFindUI),
+                (ed_glob.ID_FIND_PREVIOUS, self._searchctrl.OnUpdateFindUI)]
 
     def LoadSessionFiles(self):
         """Load files from saved session data in profile
@@ -319,6 +329,11 @@ class EdPages(FNB.FlatNotebook):
         ext_reg = syntax.ExtensionRegister()
         ext_lst = ext_reg.get(dlexer, ['txt', ])
         self.control.FindLexer(ext_lst[0])
+
+        # Set the modified callback notifier
+        doc = self.control.GetDocument()
+        doc.AddModifiedCallback(self.control.FireModified)
+
         self.Thaw()
 
     def OnCopyTabPath(self, evt):
@@ -359,6 +374,20 @@ class EdPages(FNB.FlatNotebook):
         else:
             evt.Skip()
 
+    def OnMClick(self, evt):
+        """Handle tab middle click event
+        @param evt: wx.MouseEvent
+
+        """
+        where, tabIdx = self._pages.HitTest(evt.GetPosition())
+        if where in (FNB.FNB_TAB, FNB.FNB_TAB_X):
+            # If the click is on the tab, make sure the tab is selected
+            # then close it.
+            self.SetSelection(tabIdx)
+            self.ClosePage()
+        else:
+            evt.Skip()
+
     def OnTabMenu(self, evt):
         """Show the tab context menu"""
         # Destroy any existing menu
@@ -499,7 +528,12 @@ class EdPages(FNB.FlatNotebook):
         self.LOG("[ed_pages][evt] Opened Page: %s" % filename)
 
         # Set tab image
-        self.SetPageImage(self.GetSelection(), str(self.control.GetLangId()))
+        cpage = self.GetSelection()
+        if doc.ReadOnly:
+            FNB.FlatNotebook.SetPageImage(self, cpage,
+                                          self._index[ed_glob.ID_READONLY])
+        else:
+            self.SetPageImage(cpage, str(self.control.GetLangId()))
 
         # Refocus on selected page
         self.GoCurrentPage()
@@ -640,6 +674,15 @@ class EdPages(FNB.FlatNotebook):
             if page is not None:
                 page.DoOnIdle()
 
+#            # Update document indicator state
+#            if hasattr(page, 'GetDocument'):
+#                doc = page.GetDocument()
+#                sel = self.GetSelection()
+#                img = self.GetPageImage(sel)
+#                roidx = self._index[ed_glob.ID_READONLY]
+#                if doc.ReadOnly and img != roidx:
+#                    FNB.FlatNotebook.SetPageImage(sel, roidx)
+
     def OnLeftUp(self, evt):
         """Traps clicks sent to page close buttons and
         redirects the action to the ClosePage function
@@ -675,12 +718,14 @@ class EdPages(FNB.FlatNotebook):
                   "%d to Page: %d\n" % pages)
         ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_CHANGING, (self,) + pages)
 
-    def ChangePage(self, pg_num):
+    def ChangePage(self, pg_num, old=-2):
         """Change the page and focus to the the given page id
-        @param pg_num: Page number to change 
+        @param pg_num: Page number to change
+        @keyword old: previous selection
 
         """
-        if self.GetSelection() != pg_num:
+        cpage = self.GetSelection()
+        if cpage != pg_num:
             self.SetSelection(pg_num)
 
         # Get the window that is the current page
@@ -692,7 +737,12 @@ class EdPages(FNB.FlatNotebook):
         self.frame.SetTitle(self.control.GetTitleString())
 
         # Only post page changes when the change is not from the app exiting
-        if not self.frame.IsExiting():
+        # NOTE: -2 is used as default value, cant use -1 as it comes from
+        #       page close events.
+        if old > -2:
+            cpage = old
+
+        if not self.frame.IsExiting() and cpage != pg_num:
             ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_CHANGED, (self, pg_num))
 
     def OnPageChanged(self, evt):
@@ -702,7 +752,7 @@ class EdPages(FNB.FlatNotebook):
 
         """
         cpage = evt.GetSelection()
-        self.ChangePage(cpage)
+        self.ChangePage(cpage, old=evt.GetOldSelection())
         evt.Skip()
         self.LOG("[ed_pages][evt] Page Changed to %d" % cpage)
         
@@ -787,7 +837,7 @@ class EdPages(FNB.FlatNotebook):
             return
 
         imglst = self.GetImageList()
-        if not self._index.has_key(lang_id):
+        if lang_id not in self._index:
             bmp = wx.ArtProvider.GetBitmap(lang_id, wx.ART_MENU)
             if bmp.IsNull():
                 self._index.setdefault(lang_id, \
