@@ -3,52 +3,52 @@
 # Purpose: Editra's printer class                                             #
 # Author: Cody Precord <cprecord@editra.org>                                  #
 # Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
-# Licence: wxWindows Licence                                                  #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 """
-#--------------------------------------------------------------------------#
-# FILE: ed_print                                                           #
-# AUTHOR: Cody Precord                                                     #
-# LANGUAGE: Python                                                         #
-# SUMMARY:                                                                 #
-# Provides a printer class can render the text from an stc into MemoryDC   #
-# that is used for printing. Much of the code for scaling in this file is  #
-# derived from a python module called STCPrinting written by               #
-# Riaan Booysen.                                                           #
-#                                                                          #
-# METHODS:                                                                 #
-# EdPrinter: Class for managing printing and providing print dialogs       #
-# EdPrintout: Scales and renders the given document to a printer.          #
-#                                                                          #
-#--------------------------------------------------------------------------#
+Provides a printer class can render the text from an stc into MemoryDC that is
+used for printing. Much of the code for scaling in this file is derived from a
+python module called STCPrinting written by Riaan Booysen.
+
+Classes:
+  - L{EdPrinter}: Class for managing printing and providing print dialogs
+  - L{EdPrintout}: Scales and renders the given document to a printer.
+
+@summary: Printer Classes for printing text from an STC
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: ed_print.py 51096 2008-01-08 08:03:46Z CJP $"
-__revision__ = "$Revision: 51096 $"
+__cvsid__ = "$Id: ed_print.py 57118 2008-12-05 02:03:02Z CJP $"
+__revision__ = "$Revision: 57118 $"
 
 #--------------------------------------------------------------------------#
-# Dependancies
+# Imports
 import wx
 import wx.stc
+
+# Editra Imports
+import ed_glob
 import util
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
+
 # Globals
-COLOURMODES = { 'black_white'    : wx.stc.STC_PRINT_BLACKONWHITE,
-                'colour_white'   : wx.stc.STC_PRINT_COLOURONWHITE,
-                'colour_default' : wx.stc.STC_PRINT_COLOURONWHITEDEFAULTBG,
-                'inverse'        : wx.stc.STC_PRINT_INVERTLIGHT,
-                'normal'         : wx.stc.STC_PRINT_NORMAL }
+COLOURMODES = { ed_glob.PRINT_BLACK_WHITE : wx.stc.STC_PRINT_BLACKONWHITE,
+                ed_glob.PRINT_COLOR_WHITE : wx.stc.STC_PRINT_COLOURONWHITE,
+                ed_glob.PRINT_COLOR_DEF   : wx.stc.STC_PRINT_COLOURONWHITEDEFAULTBG,
+                ed_glob.PRINT_INVERT      : wx.stc.STC_PRINT_INVERTLIGHT,
+                ed_glob.PRINT_NORMAL      : wx.stc.STC_PRINT_NORMAL }
+
 #--------------------------------------------------------------------------#
 class EdPrinter:
     """Printer Class for the editor
     @note: current font size is fixed at 12 point for printing
 
     """
-    def __init__(self, parent, stc_callable, mode='normal'):
+    def __init__(self, parent, stc_callable, mode=ed_glob.PRINT_NORMAL):
         """Initializes the Printer, the stc_callable parameter
         must be a callable function that returns an STC instance object
         @param stc_callable: function to get current stc document
@@ -107,16 +107,16 @@ class EdPrinter:
             dlg_data = printer.GetPrintDialogData()
             self.print_data = wx.PrintData(dlg_data.GetPrintData())
         printout.Destroy()
-        
-    def SetColourMode(self, mode_str):
+
+    def SetColourMode(self, mode):
         """Sets the color mode that the text is to be rendered with
-        @param mode_str: mode to set the printer to use
+        @param mode: mode to set the printer to use
         @return: whether mode was set or not
         @rtype: boolean
 
         """
-        if COLOURMODES.has_key(mode_str):
-            self.print_mode = mode_str
+        if mode in COLOURMODES:
+            self.print_mode = mode
             ret = True
         else:
             ret = False
@@ -162,7 +162,7 @@ class EdPrintout(wx.Printout):
 
         """
         line_height = self.stc.TextHeight(0)
-        
+
         # Calculate sizes
         dc = self.GetDC()
         dw, dh = dc.GetSizeTuple()
@@ -189,7 +189,7 @@ class EdPrintout(wx.Printout):
         # Page Number
         page_lbl = _("Page: %d") % page
         pg_lbl_w, pg_lbl_h = dc.GetTextExtent(page_lbl)
-        dc.DrawText(page_lbl, int(dw/scale/2 - pg_lbl_w/2), 
+        dc.DrawText(page_lbl, int(dw/scale/2 - pg_lbl_w/2),
                     int((text_area_h + margin_h) / scale + pg_lbl_h * 2))
 
         # Render the STC window into a DC for printing
@@ -200,11 +200,11 @@ class EdPrintout(wx.Printout):
         end_point = self.stc.FormatRange(True, start_pos, end_pos, dc, dc,
                                         wx.Rect(int(margin_w/scale),
                                                 int(margin_h/scale),
-                                                max_w, 
+                                                max_w,
                                                 int(text_area_h/scale)+1),
                                         wx.Rect(0, (page - 1) * \
                                                 self.lines_pp * \
-                                                line_height, max_w, 
+                                                line_height, max_w,
                                                 line_height * self.lines_pp))
 
         if end_point < end_pos:
