@@ -16,14 +16,15 @@ highlight text in a StyledTextCtrl.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 56838 2008-11-18 18:43:23Z CJP $"
-__revision__ = "$Revision: 56838 $"
+__svnid__ = "$Id: ed_search.py 57224 2008-12-10 02:38:27Z CJP $"
+__revision__ = "$Revision: 57224 $"
 
 #--------------------------------------------------------------------------#
 # Imports
 import os
 import sys
 import re
+import fnmatch
 import types
 from StringIO import StringIO
 import wx
@@ -64,6 +65,7 @@ class SearchController:
         self._data     = wx.FindReplaceData(finddlg.AFR_RECURSIVE)
         self._li_choices = list()
         self._li_sel   = 0
+        self._filters  = None
 
         # Event handlers
         self._parent.Bind(finddlg.EVT_FIND, self.OnFind)
@@ -83,8 +85,8 @@ class SearchController:
                                             (_("Find"), _("Find/Replace")),
                                             finddlg.AFR_STYLE_REPLACEDIALOG)
         elif e_id == ed_glob.ID_FIND:
-            dlg =  finddlg.AdvFindReplaceDlg(self._parent, self._data,
-                                             (_("Find"), _("Find/Replace")))
+            dlg = finddlg.AdvFindReplaceDlg(self._parent, self._data,
+                                            (_("Find"), _("Find/Replace")))
         else:
             dlg = None
 
@@ -101,6 +103,7 @@ class SearchController:
 
             dlg.SetLookinChoices(self._li_choices)
             dlg.SetLookinSelection(self._li_sel)
+            dlg.SetFileFilters(self._filters)
 
         return dlg
 
@@ -161,7 +164,7 @@ class SearchController:
         @param evt: updateui event
 
         """
-        if evt.GetId() == ed_glob.ID_FIND_NEXT:
+        if evt.GetId() in (ed_glob.ID_FIND_PREVIOUS, ed_glob.ID_FIND_NEXT):
             evt.Enable(len(self.GetData().GetFindString()))
         else:
             evt.Skip()
@@ -176,8 +179,12 @@ class SearchController:
 
         # Find next from menu event or called internally by replace
         if findnext or evt.GetEventType() == wx.wxEVT_COMMAND_MENU_SELECTED:
+            flags = data.GetFlags()
+            if evt.GetId() == ed_glob.ID_FIND_PREVIOUS:
+                flags |= finddlg.AFR_UP
+
             evt = finddlg.FindEvent(finddlg.edEVT_FIND_NEXT,
-                                    flags=data.GetFlags())
+                                    flags=flags)
             evt.SetFindString(data.GetFindString())
 
         stc = self._stc()
@@ -224,10 +231,17 @@ class SearchController:
             start, end = match
 
             if isdown:
-                stc.SetSelection(start + spos, end + spos)
+                start = start + spos
+                end = end + spos
+                stc.SetSelection(start, end)
             else:
                 stc.SetSelection(end, start)
+
+            # Ensure caret and the line its in is exposed
             stc.EnsureCaretVisible()
+            line = stc.LineFromPosition(start)
+            stc.EnsureVisible(line)
+
             self._posinfo['found'] = start
 
             ed_msg.PostMessage(ed_msg.EDMSG_UI_SB_TXT,
@@ -253,7 +267,11 @@ class SearchController:
                 if not isdown:
                     match.reverse()
                 stc.SetSelection(match[0], match[1])
+                
+                # Ensure caret and the line its in is exposed
                 stc.EnsureCaretVisible()
+                line = stc.LineFromPosition(match[0])
+                stc.EnsureVisible(line)
             else:
                 self._posinfo['found'] = -1
                 ed_msg.PostMessage(ed_msg.EDMSG_UI_SB_TXT,
@@ -292,6 +310,7 @@ class SearchController:
                                (engine.SearchInFiles, [files,], dict()))
         elif smode == finddlg.LOCATION_IN_FILES:
             path = evt.GetDirectory()
+            engine.SetFileFilters(evt.GetFileFilters())
             ed_msg.PostMessage(ed_msg.EDMSG_START_SEARCH,
                                (engine.SearchInDirectory,
                                 [path,], dict(recursive=evt.IsRecursive())))
@@ -305,16 +324,17 @@ class SearchController:
             # Save the lookin values for next time dialog is shown
             self._li_choices = self._finddlg.GetLookinChoices()
             self._li_sel = self._finddlg.GetLookinSelection()
+            self._filters = self._finddlg.GetFileFilters()
 
             # Store in profile. Only save most recent 5 in history
             if len(self._li_choices) > 5:
                 choices = self._li_choices[-5:]
             else:
                 choices = self._li_choices
-            choices.reverse()
 
             # Save the most recent choices of search locations
             Profile_Set('SEARCH_LOC', choices)
+            Profile_Set('SEARCH_FILTER', self._filters)
 
             # Destroy it
             self._finddlg.Destroy()
@@ -431,6 +451,13 @@ class SearchController:
             stc.ReplaceTarget(value)
         stc.EndUndoAction()
 
+    def SetFileFilters(self, filters):
+        """Set the file filter to use
+        @param filters: string '*.py *.pyw'
+
+        """
+        self._filters = filters
+
     def SetLookinChoices(self, choices):
         """Set the list of locations to use for the recent search
         locations.
@@ -650,7 +677,7 @@ class SearchEngine:
         @todo: implement
 
         """
-        
+        raise NotImplementedError
 
     def SearchInDirectory(self, directory, recursive=True):
         """Search in all the files found in the given directory
@@ -665,6 +692,19 @@ class SearchEngine:
         paths = [os.path.join(directory, fname)
                 for fname in os.listdir(directory) if not fname.startswith('.')]
 
+        # Filter out files that don't match the current filter(s)
+        if self._filters is not None:
+            filtered = list()
+            for fname in paths:
+                if os.path.isdir(fname):
+                    filtered.append(fname)
+                    continue
+
+                for pat in self._filters:
+                    if fnmatch.fnmatch(fname, pat):
+                        filtered.append(fname)
+            paths = filtered
+
         # Begin searching in the paths
         for path in paths:
             if recursive and os.path.isdir(path):
@@ -725,6 +765,15 @@ class SearchEngine:
         @keyword startpos: search start position
 
         """
+        raise NotImplementedError
+
+    def SetFileFilters(self, filters):
+        """Set the file filters to specify what type of files to search in
+        the filter should be a list of wild card patterns to match.
+        @param filters: list of strings ['*.py', '*.pyw']
+
+        """
+        self._filters = filters
 
     def SetFlags(self, isregex=None, matchcase=None, wholeword=None, down=None):
         """Set the search engine flags. Leaving the parameter set to None
@@ -1260,8 +1309,9 @@ class SearchResultScreen(ctrlbox.ControlBox):
  
         # Add our end message
         lines = max(0, self._list.GetLineCount() - 2)
-        msg = _("Search Complete: %d matching lines where found") % lines
-        end = u">>> %s" % msg
+        msg = _("Search Complete: %d matching lines where found.") % lines
+        msg2 = _("Files Searched: %d" % self._list.GetFileCount())
+        end = u">>> %s \t%s" % (msg, msg2)
         self._list.SetStartEndText(end + os.linesep)
 
     def OnThemeChange(self, msg):
@@ -1312,6 +1362,9 @@ class SearchResultList(outbuff.OutputBuffer):
     def __init__(self, parent):
         outbuff.OutputBuffer.__init__(self, parent)
 
+        # Attributes
+        self._files = 0
+
         # Setup
         font = Profile_Get('FONT1', 'font', wx.Font(11, wx.FONTFAMILY_MODERN, 
                                                     wx.FONTSTYLE_NORMAL, 
@@ -1332,9 +1385,15 @@ class SearchResultList(outbuff.OutputBuffer):
             outbuff.OutputBuffer.AppendUpdate(self, value)
         else:
             # Search in a new file has started
-            ed_msg.PostMessage(ed_msg.EDMSG_UI_SB_TXT,
-                               (ed_glob.SB_INFO,
-                               _("Searching in : %s") % value[1]))
+            self._files += 1
+
+            # Only updated status bar for every 10 files to reduce the overhead
+            # of updating the status bar and to improve performance of search.
+            if self._files == 1 or \
+               ((self._files / 10) > ((self._files-1) / 10)): 
+                ed_msg.PostMessage(ed_msg.EDMSG_UI_SB_TXT,
+                                   (ed_glob.SB_INFO,
+                                   _("Searching in: %s") % value[1]))
 
     def ApplyStyles(self, start, txt):
         """Set a hotspot for each search result
@@ -1350,6 +1409,11 @@ class SearchResultList(outbuff.OutputBuffer):
         else:
             self.SetStyling(len(txt), outbuff.OPB_STYLE_DEFAULT)
 
+    def Clear(self):
+        """Override OutputBuffer.Clear"""
+        self._files = 0
+        super(SearchResultList, self).Clear()
+
     def DoHotSpotClicked(self, pos, line):
         """Handle a click on a hotspot and open the file to the matched line
         @param pos: long
@@ -1368,6 +1432,13 @@ class SearchResultList(outbuff.OutputBuffer):
                     lnum = 0
                 self._OpenToLine(fname, lnum)
 
+    def GetFileCount(self):
+        """Get the number of files searched in the previous/current search job.
+        @return: int
+
+        """
+        return self._files
+
     def SetStartEndText(self, txt):
         """Add a start task or end task message to the output. Styled in
         Info style.
