@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 56950 2008-11-24 01:25:08Z CJP $"
-__revision__ = "$Revision: 56950 $"
+__svnid__ = "$Id: ed_stc.py 57306 2008-12-13 03:52:25Z CJP $"
+__revision__ = "$Revision: 57306 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -39,6 +39,7 @@ import ed_msg
 import ed_txt
 import ed_menu
 from ed_keyh import KeyHandler, ViKeyHandler
+from extern import vertedit
 
 #-------------------------------------------------------------------------#
 # Globals
@@ -101,6 +102,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         # Attributes
         self.LOG = wx.GetApp().GetLog()
         self.key_handler = KeyHandler(self)
+        self.vert_edit = vertedit.VertEdit(self)
 
         # File Attributes
         self.file = ed_txt.EdFile()
@@ -157,6 +159,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         #self.Bind(wx.stc.EVT_STC_MACRORECORD, self.OnRecordMacro)
         self.Bind(wx.stc.EVT_STC_MARGINCLICK, self.OnMarginClick)
         self.Bind(wx.stc.EVT_STC_MODIFIED, self.OnModified)
+        self.Bind(wx.stc.EVT_STC_UPDATEUI, self.OnUpdateUI)
         self.Bind(wx.EVT_KEY_DOWN, self.OnKeyDown)
         self.Bind(wx.EVT_CHAR, self.OnChar)
         self.Bind(wx.EVT_KEY_UP, self.OnKeyUp)
@@ -595,7 +598,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
     def GotoLine(self, line):
         """Move caret to begining given line number
-        @param line: line to go to
+        @param line: line to go to (int)
 
         """
         if line > self.GetLineCount():
@@ -606,8 +609,17 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             pass
 
         self.SetYCaretPolicy(wx.stc.STC_CARET_STRICT, 0)
-        wx.stc.StyledTextCtrl.GotoLine(self, line)
+        super(EditraStc, self).GotoLine(line)
         self.SetYCaretPolicy(wx.stc.STC_CARET_EVEN, 0)
+        self.PostPositionEvent()
+
+    def GotoPos(self, pos):
+        """Override StyledTextCtrl.GotoPos
+        @param pos: position in buffer to move carat to (int)
+
+        """
+        super(EditraStc, self).GotoPos(pos)
+        self.PostPositionEvent()
 
     def SetCurrentCol(self, column):
         """Set the current column position on the currently line
@@ -958,8 +970,11 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         else:
             adj = 8
 
-        self.SetMarginWidth(NUM_MARGIN, max(15, mwidth + adj))
+        nwidth = max(15, mwidth + adj)
+        if self.GetMarginWidth(NUM_MARGIN) != nwidth:
+            self.SetMarginWidth(NUM_MARGIN, nwidth)
 
+        self.vert_edit.OnModified(evt)
         wx.PostEvent(self.GetParent(), evt)
 
     def OnUpdateUI(self, evt):
@@ -968,6 +983,11 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @type evt: wx.stc.StyledTextEvent
 
         """
+        # If disabled just skip the event
+        if not self._config['brackethl']:
+            evt.Skip()
+            return
+
         brace_at_caret, brace_opposite = self.GetBracePair()
         # CallAfter necessary to reduce CG warnings on Mac
         if brace_at_caret != -1  and brace_opposite == -1:
@@ -975,6 +995,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         else:
             wx.CallAfter(self.BraceHighlight, brace_at_caret, brace_opposite)
 
+        evt.Skip()
+
     def OnMarginClick(self, evt):
         """Open and Close Folders as Needed
         @param evt: event that called this handler
@@ -1141,6 +1163,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                   ed_glob.ID_REVERT_FILE : self.RevertToSaved,
                   ed_glob.ID_KWHELPER: self.ShowKeywordHelp,
                   ed_glob.ID_CUT_LINE : self.LineCut,
+                  ed_glob.ID_COLUMN_MODE : self.ToggleColumnMode,
                   ed_glob.ID_COPY_LINE : self.LineCopy,
                   ed_glob.ID_DUP_LINE : self.LineDuplicate,
                   ed_glob.ID_BRACKETHL : self.ToggleBracketHL,
@@ -1179,8 +1202,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         if self.AutoCompActive():
             self.AutoCompCancel()
 
-        if e_obj.GetClassName() == "wxToolBar" or e_map.has_key(e_id):
-            if e_map.has_key(e_id):
+        if e_obj.GetClassName() == "wxToolBar" or e_id in e_map:
+            if e_id in e_map:
                 e_map[e_id]()
             return
 
@@ -1207,7 +1230,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.SetIndentationGuides(not bool(self.GetIndentationGuides()))
         elif e_id == ed_glob.ID_HLCARET_LINE:
             self.SetCaretLineVisible(not self.GetCaretLineVisible())
-        elif e_id in syntax.SyntaxIds():
+        elif e_id in syntax.SYNTAX_IDS:
             f_ext = syntax.GetExtFromId(e_id)
             self.LOG("[ed_stc][evt] Manually Setting Lexer to %s" % str(f_ext))
             self.FindLexer(f_ext)
@@ -1355,6 +1378,13 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         return self._config['brackethl']
 
+    def IsColumnMode(self):
+        """Is the buffer in column edit mode
+        @return: bool
+
+        """
+        return self.vert_edit.Enabled
+
     def IsComment(self, pos):
         """Is the given position in a comment region of the current buffer
         @param pos: int position in buffer
@@ -1654,11 +1684,13 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         if (switch is None and not self._config['brackethl']) or switch:
             self.LOG("[ed_stc][evt] Bracket Highlighting Turned On")
             self._config['brackethl'] = True
-            self.Bind(wx.stc.EVT_STC_UPDATEUI, self.OnUpdateUI)
         else:
             self.LOG("[ed_stc][evt] Bracket Highlighting Turned Off")
             self._config['brackethl'] = False
-            self.Unbind(wx.stc.EVT_STC_UPDATEUI)
+
+    def ToggleColumnMode(self):
+        """Toggle the column edit mode"""
+        self.vert_edit.enable(not self.vert_edit.Enabled)
 
     def ToggleLineNumbers(self, switch=None):
         """Toggles the visibility of the line number margin
@@ -1892,7 +1924,13 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             if _PGET('AUTO_TRIM_WS', 'bool', False):
                 self.TrimWhitespace()
 
-            self.file.Write(self.GetText())
+            if self.file.IsReadOnly():
+                wx.MessageBox(_("File is Read Only and cannot be saved"),
+                              _("Read Only"),
+                              style=wx.OK|wx.CENTER|wx.ICON_WARNING)
+                return True
+            else:
+                self.file.Write(self.GetText())
         except Exception, msg:
             result = False
             self.LOG("[ed_stc][err] There was an error saving %s" % path)
@@ -2098,6 +2136,12 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
     def UpdateBaseStyles(self):
         ed_style.StyleMgr.UpdateBaseStyles(self)
+        sback = self.GetItemByName('select_style')
+        if not sback.IsNull():
+            sback = sback.GetBack()
+        else:
+            sback = wx.SystemSettings.GetColour(wx.SYS_COLOUR_HIGHLIGHT)
+        self.vert_edit.SetBlockColor(sback)
         self.DefineMarkers()
 
     #---- End Style Definitions ----#
