@@ -20,8 +20,8 @@ U{http://editra.org/?page=docs&doc=ess_spec}.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_style.py 56813 2008-11-17 04:44:05Z CJP $"
-__revision__ = "$Revision: 56813 $"
+__svnid__ = "$Id: ed_style.py 57230 2008-12-10 05:40:35Z CJP $"
+__revision__ = "$Revision: 57230 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -366,7 +366,7 @@ class StyleMgr(object):
         if custom != wx.EmptyString and self.LoadStyleSheet(custom):
             self.LOG("[ed_style][info] Loaded custom style sheet %s" % custom)
         elif custom == wx.EmptyString:
-            self.SetStyles('default', DefaultStyleDictionary())
+            self.SetStyles('default', DEF_STYLE_DICT)
         else:
             self.LOG("[ed_style][err] Failed to import styles from %s" % custom)
 
@@ -378,7 +378,7 @@ class StyleMgr(object):
 
         """
         sty_dict = dict()
-        for key in DefaultStyleDictionary().keys():
+        for key in DEF_STYLE_DICT.keys():
             if key in ('select_style', 'whitespace_style'):
                 sty_dict[key] = NullStyleItem()
             else:
@@ -516,12 +516,15 @@ class StyleMgr(object):
 
         """
         if self.HasNamedStyle(name):
-            if u"%" in unicode(StyleMgr.STYLES[self.style_set][name]):
-                val = unicode(StyleMgr.STYLES[self.style_set][name]) % self.fonts
+            item = StyleMgr.STYLES[self.style_set][name]
+            ival = unicode(item)
+
+            # Set font value if need be
+            if u"%" in ival:
+                val = ival % self.fonts
                 item = StyleItem()
                 item.SetAttrFromStr(val)
-            else:
-                item = StyleMgr.STYLES[self.style_set][name]
+
             return item
         else:
             return StyleItem()
@@ -561,7 +564,7 @@ class StyleMgr(object):
         @rtype: dict
 
         """
-        return StyleMgr.STYLES.get(self.style_set, DefaultStyleDictionary())
+        return StyleMgr.STYLES.get(self.style_set, DEF_STYLE_DICT)
 
     @staticmethod
     def GetStyleSheet(sheet_name=None):
@@ -610,7 +613,7 @@ class StyleMgr(object):
         @return: whether item is in style set or not
 
         """
-        return self.GetStyleSet().has_key(name)
+        return name in self.GetStyleSet()
 
     def LoadStyleSheet(self, style_sheet, force=False):
         """Loads a custom style sheet and returns True on success
@@ -623,7 +626,7 @@ class StyleMgr(object):
         """
         if isinstance(style_sheet, basestring) and \
            os.path.exists(style_sheet) and \
-           ((force or not StyleMgr.STYLES.has_key(style_sheet)) or \
+           ((force or style_sheet not in StyleMgr.STYLES) or \
              style_sheet != self.style_set):
             reader = util.GetFileReader(style_sheet)
             if reader == -1:
@@ -632,11 +635,11 @@ class StyleMgr(object):
             ret_val = self.SetStyles(style_sheet, self.ParseStyleData(reader.read()))
             reader.close()
             return ret_val
-        elif not StyleMgr.STYLES.has_key(style_sheet):
+        elif style_sheet not in StyleMgr.STYLES:
             self.LOG("[ed_style][warn] Style sheet %s does not exists" % style_sheet)
             # Reset to default style
             Profile_Set('SYNTHEME', 'default')
-            self.SetStyles('default', DefaultStyleDictionary())
+            self.SetStyles('default', DEF_STYLE_DICT)
             return False
         else:
             self.LOG("[ed_style][info] Using cached style data")
@@ -650,7 +653,7 @@ class StyleMgr(object):
         @return: style_set with all unset attributes set to match default style
 
         """
-        if isinstance(style_set, dict) and style_set.has_key('default_style'):
+        if isinstance(style_set, dict) and 'default_style' in style_set:
             default = style_set['default_style']
             for tag in style_set:
                 if style_set[tag].IsNull():
@@ -886,7 +889,7 @@ class StyleMgr(object):
                     return False
 
             self.style_set = name
-            defaultd = DefaultStyleDictionary()
+            defaultd = DEF_STYLE_DICT
             dstyle = style_dict.get('default_style', None)
             if dstyle is None:
                 style_dict['default_style'] = defaultd['default_style']
@@ -1000,15 +1003,17 @@ class StyleMgr(object):
 
 #-----------------------------------------------------------------------------#
 # Utility Functions
-def DefaultStyleDictionary():
-    """This is the default style values that are used for styling
-    documents. Its used as a fallback for undefined values in a
-    style sheet.
-    @note: incomplete style sheets are merged against this set to ensure
-           a full set of definitions is avaiable
+
+def NullStyleItem():
+    """Create a null style item
+    @return: empty style item that cannot be merged
 
     """
-    def_dict = \
+    item = StyleItem()
+    item.null = True
+    return item
+
+DEF_STYLE_DICT = \
         {'brace_good' : StyleItem("#FFFFFF", "#0000FF", ex=["bold",]),
          'brace_bad'  : StyleItem(back="#FF0000", ex=["bold",]),
          'calltip'    : StyleItem("#404040", "#FFFFB8"),
@@ -1064,7 +1069,6 @@ def DefaultStyleDictionary():
          'userkw_style' : StyleItem(),
          'whitespace_style' : StyleItem('#838383')
          }
-    return def_dict
 
 def MergeFonts(style_dict, font_dict):
     """Does any string substitution that the style dictionary
@@ -1092,12 +1096,3 @@ def MergeStyles(styles1, styles2):
     for style in styles2:
         styles1[style] = styles2[style]
     return styles1
-
-def NullStyleItem():
-    """Create a null style item
-    @return: empty style item that cannot be merged
-
-    """
-    item = StyleItem()
-    item.null = True
-    return item
