@@ -16,8 +16,8 @@ can be installed as single file instead of dozens of individual image files.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_theme.py 56026 2008-10-02 02:58:38Z CJP $"
-__revision__ = "$Revision: 56026 $"
+__svnid__ = "$Id: ed_theme.py 57226 2008-12-10 03:13:03Z CJP $"
+__revision__ = "$Revision: 57226 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -30,7 +30,7 @@ import util
 import plugin
 from profiler import Profile_Get, Profile_Set
 import syntax.synglob as synglob
-from syntax.syntax import SyntaxIds
+from syntax.syntax import SYNTAX_IDS
 
 #--------------------------------------------------------------------------#
 
@@ -252,7 +252,8 @@ ART = { ed_glob.ID_ABOUT  : u'about.png',
         ed_glob.ID_WEB    : u'web.png',
         ed_glob.ID_ZOOM_IN : u'zoomi.png',
         ed_glob.ID_ZOOM_OUT : u'zoomo.png',
-        ed_glob.ID_ZOOM_NORMAL : u'zoomd.png'
+        ed_glob.ID_ZOOM_NORMAL : u'zoomd.png',
+        ed_glob.ID_READONLY : u'readonly.png'
 }
 
 # File Type Art
@@ -334,7 +335,7 @@ class TangoTheme(plugin.Plugin):
         @param bmp_id: Id of bitmap to look for
 
         """
-        if ART.has_key(bmp_id):
+        if bmp_id in ART:
             path = self.__GetArtPath(wx.ART_MENU, mime=False)
             if path is not None:
                 path = path + ART[bmp_id]
@@ -352,8 +353,8 @@ class TangoTheme(plugin.Plugin):
 
         """
         path = self.__GetArtPath(wx.ART_MENU, mime=True)
-        if path is not None and bmp_id in SyntaxIds():
-            if MIME_ART.has_key(bmp_id):
+        if path is not None and bmp_id in SYNTAX_IDS:
+            if bmp_id in MIME_ART:
                 req = path + MIME_ART[bmp_id]
                 if os.path.exists(req):
                     return wx.Bitmap(req, wx.BITMAP_TYPE_PNG)
