@@ -12,8 +12,8 @@ Text/Unicode handling functions and File wrapper class
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_txt.py 56950 2008-11-24 01:25:08Z CJP $"
-__revision__ = "$Revision: 56950 $"
+__svnid__ = "$Id: ed_txt.py 57037 2008-11-30 03:59:11Z CJP $"
+__revision__ = "$Revision: 57037 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -203,6 +203,16 @@ class EdFile(object):
         """
         return self.open
 
+    def IsReadOnly(self):
+        """Is the file Read Only
+        @return: bool
+
+        """
+        if os.path.exists(self.path):
+            return not os.access(self.path, os.R_OK|os.W_OK)
+        else:
+            return False
+
     @property
     def Modtime(self):
         """File modification time propery"""
@@ -260,6 +270,10 @@ class EdFile(object):
         else:
             raise ReadError, self.last_err
 
+    @property
+    def ReadOnly(self):
+        return self.IsReadOnly()
+
     def RemoveModifiedCallback(self, callback):
         """Remove a registered callback
         @param callback: callable to remove
