@@ -8,18 +8,13 @@
 ###############################################################################
 
 """
-FILE: plugdlg.py                                                         
-AUTHOR: Cody Precord                                                     
-LANGUAGE: Python                                                         
-SUMMARY:                                                                 
- Provides a dialog for downloading, installing and configuring plugins for 
-Editra.
-                                                                      
+Provides a dialog for downloading, installing and configuring plugins or Editra.
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: plugdlg.py 52236 2008-03-02 04:22:15Z CJP $"
-__revision__ = "$Revision: 52236 $"
+__cvsid__ = "$Id: plugdlg.py 57118 2008-12-05 02:03:02Z CJP $"
+__revision__ = "$Revision: 57118 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -38,6 +33,7 @@ import ed_event
 import plugin
 import util
 import eclib.pstatbar as pstatbar
+import eclib.elistmix as elistmix
 
 #--------------------------------------------------------------------------#
 # Globals
@@ -58,13 +54,13 @@ def MakeThemeTool(tool_id):
     @todo: why does drawing a bitmap overlay on gtk not draw on transparent area
 
     """
-    osize = Profile_Get('ICON_SZ', 'size_tuple', (24, 24))
+    osize = Profile_Get('ICON_SZ', default=(24, 24))
     Profile_Set('ICON_SZ', (32, 32))
     base = wx.ArtProvider.GetBitmap(str(tool_id), wx.ART_TOOLBAR)
     Profile_Set('ICON_SZ', osize)
     if not base.IsOk() or base.GetSize() != (32, 32):
-        base = wx.ArtProvider.GetBitmap(wx.ART_WARNING, 
-                                        wx.ART_TOOLBAR, 
+        base = wx.ArtProvider.GetBitmap(wx.ART_WARNING,
+                                        wx.ART_TOOLBAR,
                                         size=(32, 32))
 
     over = wx.ArtProvider.GetBitmap(str(ed_glob.ID_PLUGMGR), wx.ART_MENU)
@@ -78,7 +74,7 @@ def MakeThemeTool(tool_id):
         mdc.SelectObject(wx.NullBitmap)
 
     return base
-    
+
 #--------------------------------------------------------------------------#
 
 class PluginDialog(wx.Frame):
@@ -100,7 +96,7 @@ class PluginDialog(wx.Frame):
         sizer = wx.BoxSizer(wx.VERTICAL)
         self.SetStatusBar(pstatbar.ProgressStatusBar(self, style=wx.SB_FLAT))
         self._nb = PluginPages(self)
-        
+
         # Layout Dialog
         sizer.Add(self._nb, 1, wx.EXPAND)
         self._title = title
@@ -177,11 +173,11 @@ class PluginPages(wx.Toolbook):
         self.SetImageList(self._imglst)
 
         # Add Pages
-        self.AddPage(self._config, _("Configure"), 
+        self.AddPage(self._config, _("Configure"),
                      imageId=self._imgind[CONFIG_PG])
-        self.AddPage(self._download, _("Download"), 
+        self.AddPage(self._download, _("Download"),
                      imageId=self._imgind[DOWNLOAD_PG])
-        self.AddPage(self._install, _("Install"), 
+        self.AddPage(self._install, _("Install"),
                      imageId=self._imgind[INSTALL_PG])
         self.SetSelection(CONFIG_PG)
 
@@ -235,10 +231,10 @@ class ConfigPanel(wx.Panel):
 
         # Attrtibutes
         self._list = PluginListCtrl(self)
-        
+
         # Layout Panel
         sizer = wx.BoxSizer(wx.VERTICAL)
-        sizer.Add(wx.StaticText(self, wx.ID_ANY, 
+        sizer.Add(wx.StaticText(self, wx.ID_ANY,
                    _("To enable a plugin check the box next to its label")),
                    0, wx.ALIGN_CENTER_HORIZONTAL)
         sizer.Add((10, 10))
@@ -250,7 +246,7 @@ class ConfigPanel(wx.Panel):
 
     def GetItemIdentifier(self, name):
         """Gets the named item and returns its identifier. The
-        identifier is the combination of the name and version 
+        identifier is the combination of the name and version
         strings.
         @param name: name of item in list
         @type name: string
@@ -313,7 +309,7 @@ class ConfigPanel(wx.Panel):
             mod = sys.modules.get(item)
             pin = PluginData()
             pin.SetName(item)
-            pin.SetDescription(getattr(mod, '__doc__', 
+            pin.SetDescription(getattr(mod, '__doc__',
                                        _("No Description Available")))
             pin.SetAuthor(getattr(mod, '__author__', _("Unknown")))
             pin.SetVersion(str(getattr(mod, '__version__', _("Unknown"))))
@@ -377,7 +373,12 @@ class DownloadPanel(wx.Panel):
 
     def _ResultCatcher(self, delayedResult):
         """Catches the results from the download worker threads"""
-        frame = self.GetGrandParent()
+        # Check if result has come after the window is dead
+        try:
+            frame = self.GetGrandParent()
+        except wx.PyDeadObjectError:
+            return
+
         self._eggcount = self._eggcount - 1
         try:
             result = delayedResult.get()
@@ -396,13 +397,15 @@ class DownloadPanel(wx.Panel):
 
     def _UpdateCatcher(self, delayedResult):
         """Catches the results from the download worker threads"""
-        frame = self.GetGrandParent()
         try:
+            frame = self.GetGrandParent()
             result = delayedResult.get()
             if len(result):
                 self._p_list = self.FormatPluginList(result)
                 self.PopulateList()
                 frame.SetStatusText(_("Select plugins to download"), 0)
+        except wx.PyDeadObjectError:
+            return
         except Exception, msg:
             util.Log("[plugdlg][err] Download failed " + str(msg))
             frame.SetStatusText(_("Unable to retrieve plugin list"), 0)
@@ -521,7 +524,7 @@ class DownloadPanel(wx.Panel):
             else:
                 self._downlb.Disable()
 
-            if self._dl_list.has_key(pin):
+            if pin in self._dl_list:
                 del self._dl_list[pin]
 
     def PopulateList(self):
@@ -554,14 +557,14 @@ class DownloadPanel(wx.Panel):
 
         """
         # Removed downloaded data
-        if self._eggbasket.has_key(item):
+        if item in self._eggbasket:
             del self._eggbasket[item]
 
         # Remove download entry data
         match = self.EGG_PATTERN(item)
         if match:
             plugin_name = match.group('name').lower()
-            if self._dl_list.has_key(plugin_name):
+            if plugin_name in self._dl_list:
                 del self._dl_list[plugin_name]
 
     def UpdateList(self, url=PLUGIN_REPO):
@@ -590,7 +593,7 @@ def _GetPluginListData(url=PLUGIN_REPO):
     """Gets the list of plugins and their related meta data
     as a string and returns it.
     @return: list of data of available plugins from website
-    
+
     """
     text = u''
     try:
@@ -660,7 +663,7 @@ class InstallPanel(wx.Panel):
                              "and hit Delete or Backspace."))
         self._install = wx.ListBox(self, wx.ID_ANY, style=wx.LB_SORT)
         self._install.SetToolTip(toolt)
-        self._install.SetDropTarget(util.DropTargetFT(self._install, 
+        self._install.SetDropTarget(util.DropTargetFT(self._install,
                                                       None, self.OnDrop))
         self._instb = wx.Button(self, self.ID_INSTALL, _("Install"))
         self._instb.Disable()
@@ -677,7 +680,7 @@ class InstallPanel(wx.Panel):
 
         # Layout Panel
         sizer = wx.BoxSizer(wx.VERTICAL)
-        sizer.AddMany([(lbl, 0, wx.ALIGN_CENTER), 
+        sizer.AddMany([(lbl, 0, wx.ALIGN_CENTER),
                        (self._install, 1, wx.EXPAND),
                        ((5, 5))])
         bsizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -740,7 +743,7 @@ class InstallPanel(wx.Panel):
             grand_p = self.GetTopLevelParent()
             grand_p.SetStatusText(_("Successfully Installed Plugins"), 0)
             dlg = wx.MessageDialog(self, _("Go to configuration page?"),
-                                   _("Finished Installing Plugins"), 
+                                   _("Finished Installing Plugins"),
                                    style=wx.YES_NO | wx.CENTER | \
                                          wx.ICON_INFORMATION)
             result = dlg.ShowModal()
@@ -753,7 +756,7 @@ class InstallPanel(wx.Panel):
             self._instb.Disable()
         else:
             self.GetGrandParent().SetStatusText(_("Error"), 1)
-            dlg = wx.MessageDialog(self, 
+            dlg = wx.MessageDialog(self,
                                    _("Failed to install %d plugins") % \
                                    self._install.GetCount(),
                                    _("Installation Error"),
@@ -844,9 +847,10 @@ class InstallPanel(wx.Panel):
 
 #--------------------------------------------------------------------------#
 
-class PluginListCtrl(wx.ListCtrl, 
+class PluginListCtrl(wx.ListCtrl,
                      listmix.ListCtrlAutoWidthMixin,
-                     listmix.CheckListCtrlMixin):
+                     listmix.CheckListCtrlMixin,
+                     elistmix.ListRowHighlighter):
     """Creates a list control for displaying plugins and configuring them."""
     PLUGIN_COL   = 0
     DESCRIPT_COL = 1
@@ -858,9 +862,10 @@ class PluginListCtrl(wx.ListCtrl,
         @param parent: parent window of this control
 
         """
-        wx.ListCtrl.__init__(self, parent, wx.ID_ANY, 
-                             wx.DefaultPosition, wx.DefaultSize, 
-                             style=wx.LC_REPORT | wx.LC_VRULES | wx.LC_HRULES)
+        wx.ListCtrl.__init__(self, parent, wx.ID_ANY,
+                             wx.DefaultPosition, wx.DefaultSize,
+                             style=wx.LC_REPORT | wx.LC_VRULES)
+        elistmix.ListRowHighlighter.__init__(self)
 
         self.InsertColumn(self.PLUGIN_COL, _("Plugin"))
         self.InsertColumn(self.DESCRIPT_COL, _("Description"))
@@ -890,7 +895,7 @@ class PluginListCtrl(wx.ListCtrl,
         @postcondition: checkbox is checked/unchecked and parent is notified
 
         """
-        evt = ed_event.NotificationEvent(ed_event.edEVT_NOTIFY, 
+        evt = ed_event.NotificationEvent(ed_event.edEVT_NOTIFY,
                                          index, flag, self)
         wx.PostEvent(self.GetParent(), evt)
         listmix.CheckListCtrlMixin.OnCheckItem(self, index, flag)
@@ -908,15 +913,15 @@ class PluginListCtrl(wx.ListCtrl,
             if pname < self.GetItemText(item):
                 self.InsertStringItem(item, pi_data.GetName().strip())
                 self.SetStringItem(item, 1, pi_data.GetDescription().strip())
-                self.SetStringItem(item, 2, re.sub(r"\<+.*\>", '', 
+                self.SetStringItem(item, 2, re.sub(r"\<+.*\>", '',
                                                    pi_data.GetAuthor().strip()))
                 self.SetStringItem(item, 3, pi_data.GetVersion().strip())
                 self.CheckItem(item, check)
                 break
         else:
-            self.Append((pi_data.GetName().strip(), 
-                         pi_data.GetDescription().strip(), 
-                         re.sub(r"\<+.*\>", '', pi_data.GetAuthor().strip()), 
+            self.Append((pi_data.GetName().strip(),
+                         pi_data.GetDescription().strip(),
+                         re.sub(r"\<+.*\>", '', pi_data.GetAuthor().strip()),
                          pi_data.GetVersion().strip()))
 
             self.CheckItem(self.GetItemCount()-1, check)
