@@ -12,8 +12,8 @@ This file contains various helper functions and utilities that the program uses.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: util.py 56941 2008-11-23 17:20:07Z CJP $"
-__revision__ = "$Revision: 56941 $"
+__svnid__ = "$Id: util.py 57222 2008-12-09 20:01:37Z CJP $"
+__revision__ = "$Revision: 57222 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -139,10 +139,22 @@ class DropTargetFT(wx.PyDropTarget):
                is not moved.
 
         """
+        stc = self.window
         if self._tmp is None:
+            val = stc.DoDragOver(x_cord, y_cord, drag_result)
+            cline = stc.PositionFromPoint(wx.Point(x_cord, y_cord))
+            if cline != wx.stc.STC_INVALID_POSITION:
+                cline = stc.LineFromPosition(cline)
+                fline = stc.GetFirstVisibleLine()
+                lline = stc.GetLastVisibleLine()
+                if (cline - fline) < 3:
+                    stc.ScrollLines(-2)
+                elif lline - cline < 3:
+                    stc.ScrollLines(2)
+                else:
+                    pass
             return drag_result
         else:
-            stc = self.window
             point = wx.Point(x_cord, y_cord)
             self._tmp.BeginDrag(point - self._lastp, stc)
             self._tmp.Hide()
@@ -151,7 +163,7 @@ class DropTargetFT(wx.PyDropTarget):
             self._tmp.Show()
             self._tmp.RedrawImage(self._lastp, point, True, True)
             self._lastp = point
-            return drag_result
+        return drag_result
 
     def OnData(self, x_cord, y_cord, drag_result):
         """Gets and processes the dropped data
