@@ -7,8 +7,8 @@
 ###############################################################################
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: testStyleMgr.py 55150 2008-08-21 19:37:52Z CJP $"
-__revision__ = "$Revision: 55150 $"
+__svnid__ = "$Id: testStyleMgr.py 57230 2008-12-10 05:40:35Z CJP $"
+__revision__ = "$Revision: 57230 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -33,7 +33,7 @@ class StyleMgrTest(unittest.TestCase):
     def setUp(self):
         self.app = EdApp(False)
         self.mgr = ed_style.StyleMgr()
-        self.dd = ed_style.DefaultStyleDictionary()
+        self.dd = ed_style.DEF_STYLE_DICT
         self.bstr = ["fore:#000000", "back:#FFFFFF",
                      "face:%(primary)s", "size:%(size)d"]
 
